==> kplatforms-4.1.23.tar.gz: kplatforms/scripts/auto.sh <==
#!/usr/bin/env bash

PLATFORMS=(Drupal7 CiviCRM50-D7 Drupal9)
REMOVED_MODULES_LOG_FILE="removed_modules.log"

# xpath avec apt: libxml-xpath-perl
REQUIRED_TOOLS=(jq xpath)
MISSING_TOOLS=""

for tool in "${REQUIRED_TOOLS[@]}" ; do
    [[ -z "$(command -v "$tool")" ]] && MISSING_TOOLS="$MISSING_TOOLS $tool"
done
if [[ -n "${MISSING_TOOLS}" ]] ; then
    printf "[-] You are missing the following tools: %s\n" "${MISSING_TOOLS}"
    exit 1
fi

# first item is 'start' rather than latest tag for pressflow/7
NEW_VERSION_7=$(curl https://api.github.com/repos/pressflow/7/tags 2>/dev/null | jq -r .[1].name)
NEW_VERSION_7_CIVI=$(curl https://api.github.com/repos/civicrm/civicrm-core/tags 2>/dev/null | jq -r .[0].name)
NEW_VERSION_9=$(curl https://git.drupalcode.org/project/drupal/-/tags?format=atom 2>/dev/null \
    | xpath -e '//entry/title/text()' 2> /dev/null| grep --color=never '^9' | sort -r | head -1)

CURRENT_VERSION_7=$(grep 'projects\[drupal\]\[download\]\[tag\]' includes/7/core.make | sed -e 's/.* = \(.*\)$/\1/')
CURRENT_VERSION_7_CIVI=$(grep 'libraries\[civicrm\]\[download\]\[url\]' includes/7/civicrm/civicrm-50.make \
    | sed -e 's/^.*civicrm-\(.*\)-drupal.*$/\1/')
CURRENT_VERSION_9=$(jq .require includes/9/composer.json | jq -r '.["drupal/core-recommended"]')

printf "**************************************************\n\n"
printf "[+] Drupal update !\n"
printf "[+] platform\tcurrent\t\tlatest\n"
printf "[+] --------\t-------\t\t------\n"
printf "[+] DRUPAL7\t%s\t%s\n" "${CURRENT_VERSION_7}" "${NEW_VERSION_7}"
printf "[+] D7_CIVI\t%s\t\t%s\n" "${CURRENT_VERSION_7_CIVI}" "${NEW_VERSION_7_CIVI}"
printf "[+] DRUPAL9\t%s\t\t%s\n" "${CURRENT_VERSION_9}" "${NEW_VERSION_9}"
printf "**************************************************\n\n"

TEMPLATES=("7-core.make" "civicrm-50.make" "9-compose.json")
END_FILES=("7/core.make" "7/civicrm/civicrm-50.make" "9/composer.json")
# shellcheck disable=SC2016
VAR_NAME=('\${DRUPAL7}' '\${D7_CIVI}' '\${DRUPAL9}')
VERSIONS=("${NEW_VERSION_7}" "${NEW_VERSION_7_CIVI}" "${NEW_VERSION_9}")

git pull

for i in "${!TEMPLATES[@]}" ; do
    sed -e "s/${VAR_NAME[$i]}/${VERSIONS[$i]}/" "templates/${TEMPLATES[$i]}" > "includes/${END_FILES[$i]}"
done

# 4. create empty build dir
sudo rm -rf build2 ; mv build build2 ; mkdir build

# 5. rebuild kplatforms image
docker build -t kplatforms .

# 6. build new kplatforms
for platform in "${PLATFORMS[@]}"; do
    logfile="build-${platform}.log"
    docker run --rm -it -v "$PWD":/src kplatforms:latest /src/scripts/build-kplatforms.sh "$platform" | tee -a "$logfile"
    # CHECK FOR PACKAGES 'removed'
    printf "[+] REMOVED MODULES in %s:\n\n" "${platform}" >> "${REMOVED_MODULES_LOG_FILE}"
    grep 'removed' "$logfile" >> "${REMOVED_MODULES_LOG_FILE}"
done


# 7. test kplatforms
docker run --rm -it -v "$PWD":/src kplatforms:latest /src/scripts/test-kplatforms.sh

# 8. check for removed modules
printf "**************************************************\n\n"
printf "[+] CHECK FOR ANY REMOVED MODULES\n"
printf "**************************************************\n\n"
cat "${REMOVED_MODULES_LOG_FILE}"

# 9. copy lockfiles
cp -t lockfiles ./build/*.lock ./build/*.txt

# 10. generate release notes
./scripts/make-releasenotes.sh > release_notes.txt

==> kplatforms-4.1.25.tar.gz: kplatforms/scripts/auto.sh <==
#!/usr/bin/env bash

PLATFORMS=(Drupal7 CiviCRM50-D7 Drupal9)
REMOVED_MODULES_LOG_FILE="removed_modules.log"

# xpath avec apt: libxml-xpath-perl
REQUIRED_TOOLS=(jq xpath)
MISSING_TOOLS=""

for tool in "${REQUIRED_TOOLS[@]}" ; do
    [[ -z "$(command -v "$tool")" ]] && MISSING_TOOLS="$MISSING_TOOLS $tool"
done
if [[ -n "${MISSING_TOOLS}" ]] ; then
    printf "[-] You are missing the following tools: %s\n" "${MISSING_TOOLS}"
    exit 1
fi

# first item is 'start' rather than latest tag for pressflow/7
NEW_VERSION_7=$(curl https://api.github.com/repos/pressflow/7/tags 2>/dev/null | jq -r .[1].name)
NEW_VERSION_7_CIVI=$(curl https://api.github.com/repos/civicrm/civicrm-core/tags 2>/dev/null | jq -r .[0].name)
# "sort -V" for 'version' and "grep -v '-'" to exclude alpha/beta/rc releases
NEW_VERSION_9=$(curl https://git.drupalcode.org/project/drupal/-/tags?format=atom 2>/dev/null \
    | xpath -e '//entry/title/text()' 2> /dev/null| grep --color=never '^9' | sort -rV | grep -v '-' | head -1)

CURRENT_VERSION_7=$(grep 'projects\[drupal\]\[download\]\[tag\]' includes/7/core.make | sed -e 's/.* = \(.*\)$/\1/')
CURRENT_VERSION_7_CIVI=$(grep 'libraries\[civicrm\]\[download\]\[url\]' includes/7/civicrm/civicrm-50.make \
    | sed -e 's/^.*civicrm-\(.*\)-drupal.*$/\1/')
CURRENT_VERSION_9=$(jq .require includes/9/composer.json | jq -r '.["drupal/core-recommended"]')

printf "**************************************************\n\n"
printf "[+] Drupal update !\n"
printf "[+] platform\tcurrent\t\tlatest\n"
printf "[+] --------\t-------\t\t------\n"
printf "[+] DRUPAL7\t%s\t%s\n" "${CURRENT_VERSION_7}" "${NEW_VERSION_7}"
printf "[+] D7_CIVI\t%s\t\t%s\n" "${CURRENT_VERSION_7_CIVI}" "${NEW_VERSION_7_CIVI}"
printf "[+] DRUPAL9\t%s\t\t%s\n" "${CURRENT_VERSION_9}" "${NEW_VERSION_9}"
printf "**************************************************\n\n"

TEMPLATES=("7-core.make" "civicrm-50.make" "9-compose.json")
END_FILES=("7/core.make" "7/civicrm/civicrm-50.make" "9/composer.json")
# shellcheck disable=SC2016
VAR_NAME=('\${DRUPAL7}' '\${D7_CIVI}' '\${DRUPAL9}')
VERSIONS=("${NEW_VERSION_7}" "${NEW_VERSION_7_CIVI}" "${NEW_VERSION_9}")

git pull

for i in "${!TEMPLATES[@]}" ; do
    sed -e "s/${VAR_NAME[$i]}/${VERSIONS[$i]}/" "templates/${TEMPLATES[$i]}" > "includes/${END_FILES[$i]}"
done

# 4. create empty build dir
sudo rm -rf build2 ; mv build build2 ; mkdir build

# 5. rebuild kplatforms image
docker build -t kplatforms .

# 6. build new kplatforms
for platform in "${PLATFORMS[@]}"; do
    logfile="build-${platform}.log"
    docker run --rm -it -v "$PWD":/src kplatforms:latest /src/scripts/build-kplatforms.sh "$platform" | tee -a "$logfile"
    # CHECK FOR PACKAGES 'removed'
    printf "[+] REMOVED MODULES in %s:\n\n" "${platform}" >> "${REMOVED_MODULES_LOG_FILE}"
    grep 'removed' "$logfile" >> "${REMOVED_MODULES_LOG_FILE}"
done


# 7. test kplatforms
docker run --rm -it -v "$PWD":/src kplatforms:latest /src/scripts/test-kplatforms.sh

# 8. check for removed modules
printf "**************************************************\n\n"
printf "[+] CHECK FOR ANY REMOVED MODULES\n"
printf "**************************************************\n\n"
cat "${REMOVED_MODULES_LOG_FILE}"

# 9. copy lockfiles
cp -t lockfiles ./build/*.lock ./build/*.txt

# 10. generate release notes
./scripts/make-releasenotes.sh > release_notes.txt
